//******************************************************************************
//   MSP430x54x Demo - Software Toggle P1.0 from LPM3 (ACLK = VLO)
//
//   Description: Toggle P1.0 by xor'ing P1.0 with WDT LPM3 wake.
//   ACLK = VLO = 12kHz, MCLK = SMCLK = default DCO
//   Note: SVS(H,L) & SVM(H,L) not disabled
//
//                 MSP430x5438
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |             P1.0|-->LED
//
//   w. Goh
//   Texas Instruments Inc.
//   November 2008
//   Built with CCE Version: 3.2.2 and IAR Embedded Workbench Version: 4.11B
//******************************************************************************
#include  "msp430x54x.h"

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Hold WDT for clock/port configuration
 
  UCSCTL4 |= SELA_1;                        // ACLK = VLO
  
  P1DIR = 0xFF;P2DIR = 0xFF;P3DIR = 0xFF;P4DIR = 0xFF;P5DIR = 0xFF;P6DIR = 0xFF;
  P7DIR = 0xFF;P8DIR = 0xFF;P9DIR = 0xFF;P10DIR = 0xFF;P11DIR = 0xFF;PJDIR=0xFF;
  P1OUT = 0x00;P2OUT = 0x00;P3OUT = 0x00;P4OUT = 0x00;P5OUT = 0x00;P6OUT = 0x00;
  P7OUT = 0x00;P8OUT = 0x00;P9OUT = 0x00;P10OUT = 0x00;P11OUT = 0x00;PJOUT=0x00;
  
  WDTCTL = WDT_ADLY_1000;                   // WDT ~1sec*3 ACLK, interval timer
  SFRIE1 |= WDTIE;                          // Enable WDT interrupt

  __bis_SR_register(LPM3_bits + GIE);       // Enter LPM3 w/interrupt
  __no_operation();
}

// Watchdog Timer interrupt service routine
#pragma vector = WDT_VECTOR
__interrupt void watchdog_timer(void)
{
  P1OUT ^= 0x01;                            // Toggle P1.0 using exclusive-OR
}
