//******************************************************************************
//  MSP430F54x Demo - FLL+, Runs Internal DCO at 2.45MHz
//
//  Description: This program demonstrates setting the internal DCO to run at
//  2.45MHz with auto-calibration by the FLL+ circuitry.
//  ACLK = REFO = 32768Hz, MCLK = SMCLK = DCO = (74+1) x REFO = 2457600Hz	
//
//                MSP430F5438
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |            P11.1|--> MCLK = 2.45MHz
//            |                 |
//            |            P11.0|--> ACLK = 32kHz
//            |                 |
//
//   M Smertneck / W. Goh
//   Texas Instruments Inc.
//   September 2008
//   Built with CCE Version: 3.2.2 and IAR Embedded Workbench Version: 4.11B
//******************************************************************************

#include "msp430x54x.h"

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  UCSCTL1 = DCORSEL_4;                      // 2MHz nominal DCO
  UCSCTL2 = 74;                             // Set DCO Multiplier for 2.45MHz
                                            // (N + 1) * FLLRef = Fdco
                                            // (74 + 1) * 32768 = 2.45MHz

  P11DIR = BIT1+BIT0;                       // P11.0 & P11.1 to output direction
  P11SEL = BIT1+BIT0;                       // P11.0 & P11.1 to output MCLK & ACLK

  while(1);                                 // Loop in place
}

